==> wheezy.http-0.1.358.tar.gz: wheezy.http-0.1.358/README.md <==
# wheezy.http

[![Build Status](https://travis-ci.org/akornatskyy/wheezy.http.svg?branch=master)](https://travis-ci.org/akornatskyy/wheezy.http)
[![Coverage Status](https://coveralls.io/repos/github/akornatskyy/wheezy.http/badge.svg?branch=master)](https://coveralls.io/github/akornatskyy/wheezy.http?branch=master)
[![Documentation Status](https://readthedocs.org/projects/wheezyhttp/badge/?version=latest)](https://wheezyhttp.readthedocs.io/en/latest/?badge=latest)
[![pypi version](https://badge.fury.io/py/wheezy.http.svg)](https://badge.fury.io/py/wheezy.http)

[wheezy.http](https://pypi.org/project/wheezy.http/) is a
[python](http://www.python.org) package written in pure Python code. It
is a lightweight http library for things like request, response,
headers, cookies and many others. It a wrapper around the
[WSGI](http://www.python.org/dev/peps/pep-3333) request environment.

It is optimized for performance, well tested and documented.

Resources:

- [source code](https://github.com/akornatskyy/wheezy.http),
  [examples](https://github.com/akornatskyy/wheezy.http/tree/master/demos)
  and [issues](https://github.com/akornatskyy/wheezy.http/issues)
  tracker are available on
  [github](https://github.com/akornatskyy/wheezy.http)
- [documentation](https://wheezyhttp.readthedocs.io/en/latest/)

## Install

[wheezy.http](https://pypi.org/project/wheezy.http/) requires
[python](https://www.python.org) version 2.4 to 2.7 or 3.2+. It is
independent of operating system. You can install it from
[pypi](https://pypi.org/project/wheezy.http/) site:

```sh
pip install -U wheezy.http
```

If you run into any issue or have comments, go ahead and add on
[github](https://github.com/akornatskyy/wheezy.http).

==> wheezy.http-3.0.0.tar.gz: wheezy.http-3.0.0/README.md <==
# wheezy.http

[![Build Status](https://travis-ci.org/akornatskyy/wheezy.http.svg?branch=master)](https://travis-ci.org/akornatskyy/wheezy.http)
[![Coverage Status](https://coveralls.io/repos/github/akornatskyy/wheezy.http/badge.svg?branch=master)](https://coveralls.io/github/akornatskyy/wheezy.http?branch=master)
[![Documentation Status](https://readthedocs.org/projects/wheezyhttp/badge/?version=latest)](https://wheezyhttp.readthedocs.io/en/latest/?badge=latest)
[![pypi version](https://badge.fury.io/py/wheezy.http.svg)](https://badge.fury.io/py/wheezy.http)

[wheezy.http](https://pypi.org/project/wheezy.http/) is a
[python](http://www.python.org) package written in pure Python code. It
is a lightweight http library for things like request, response,
headers, cookies and many others. It a wrapper around the
[WSGI](http://www.python.org/dev/peps/pep-3333) request environment.

It is optimized for performance, well tested and documented.

Resources:

- [source code](https://github.com/akornatskyy/wheezy.http),
  [examples](https://github.com/akornatskyy/wheezy.http/tree/master/demos)
  and [issues](https://github.com/akornatskyy/wheezy.http/issues)
  tracker are available on
  [github](https://github.com/akornatskyy/wheezy.http)
- [documentation](https://wheezyhttp.readthedocs.io/en/latest/)

## Install

[wheezy.http](https://pypi.org/project/wheezy.http/) requires
[python](https://www.python.org) version 3.6+. It is independent of operating
system. You can install it from [pypi](https://pypi.org/project/wheezy.http/)
site:

```sh
pip install -U wheezy.http
```

If you run into any issue or have comments, go ahead and add on
[github](https://github.com/akornatskyy/wheezy.http).
